import machine, time, math
from machine import Pin, I2C
import ssd1306


class HCSR04:
    def __init__(self, trigger_pin, echo_pin, echo_timeout_us=500*2*30):
        self.echo_timeout_us = echo_timeout_us
        # Init trigger pin (out)
        self.trigger = Pin(trigger_pin, mode=Pin.OUT, pull=None)
        self.trigger.value(0)
        # Init echo pin (in)
        self.echo = Pin(echo_pin, mode=Pin.IN, pull=None)

    def _send_pulse_and_wait(self):
        self.trigger.value(0) # Stabilize the sensor
        time.sleep_us(5)
        self.trigger.value(1)
        # Send a 10us pulse.
        time.sleep_us(10)
        self.trigger.value(0)
        try:
            pulse_time = machine.time_pulse_us(self.echo, 1, self.echo_timeout_us)
            return pulse_time
        except OSError as ex:
            if ex.args[0] == 110: # 110 = ETIMEDOUT
                raise OSError('Out of range')
            raise ex

    def distance_mm(self):
        pulse_time = self._send_pulse_and_wait()
        mm = pulse_time * 100 // 582
        return mm

    def distance_cm(self):
        pulse_time = self._send_pulse_and_wait()
        cms = (pulse_time / 2) / 29.1
        return cms
    def distance_m(self):
        pulse_time = self._send_pulse_and_wait()
        cms = (pulse_time / 2) / 29.1
        ms=cms/100
        return ms
    
#tu zacznij pisac swoj kod
i2c = I2C(scl=Pin(13), sda=Pin(15))
oled = ssd1306.SSD1306_I2C(128,64,i2c)
oled.fill(0)
counter = 0;
sensor = HCSR04(trigger_pin=5, echo_pin=4, echo_timeout_us=10000)
while True:
    s=0
    for i in range(10):
        s=s+sensor.distance_m()
        time.sleep(0.01)
    s=s/10
    print(s)
    if(s<=0.3 and s>=0.1):
        counter=counter+1
        if(counter == 1):
            s0 = s
    else:
        if(s<0.1):
            sn = s
            czas=counter*0.1
            droga = s0-sn
            break
print("czas: ", czas)
print("droga: ", droga)

g = 9.81
a = (2*droga)/(czas*czas)
#Tu wprowadź wymiary rampy
l=38 #długość
h=11.5 #Wysokość
alfa = math.asin(h/38)
u = math.tan(alfa) - (a/(g*math.cos(alfa)))
print("przys: ", a)
print("kat: ", (alfa*360/(2*3.14)))
print("wsp tarcia: ", u)
oled.text('wpolczynnik', 5, 14, 1)
oled.text('tarcia: ', 5, 24, 1)
oled.text('u = ', 5, 34, 1)
mi = str(u)
oled.text(mi, 45, 34, 1)
oled.show()

    